macro_rules! spawn {
($fut:expr) => { ... };
}Expand description
Spawn a fiber.
This macro supports both standard futures and custom tasks defined via #[task].
macro_rules! spawn {
($fut:expr) => { ... };
}Spawn a fiber.
This macro supports both standard futures and custom tasks defined via #[task].